@@ -1,10 +1,14 @@
 import asyncio
-from inspect import isawaitable
-from typing import Union, Callable, Optional, Any, Awaitable, List
+import logging
 import types
+from inspect import isawaitable
+from typing import Any, Awaitable, Callable, List, Optional, Union
+
+from interactions.api.dispatch import Listener  # just to avoid ide things
 
 import interactions
-from interactions.api.dispatch import Listener  # just to avoid ide things
+
+logger = logging.getLogger("wait_for")
 
 
 class ExtendedListener(interactions.api.dispatch.Listener):
@@ -16,9 +20,16 @@ class ExtendedListener(interactions.api.dispatch.Listener):
         super().dispatch(name, *args, **kwargs)
 
         futs = self.extra_events.get(name, [])
+        if futs:
+            logger.debug(f"Resolving {len(futs)} futures")
 
         for fut in futs:
-            fut.set_result(args)
+            if not fut.done():
+                fut.set_result(args)
+            else:
+                logger.debug(
+                    f"A future for the {name} event was already {'cancelled' if fut.cancelled() else 'resolved'}"
+                )
 
             futs.remove(fut)
 
@@ -44,25 +55,6 @@ class ExtendedListener(interactions.api.dispatch.Listener):
 interactions.api.dispatch.Listener = ExtendedListener
 
 
-class ExtendedWebSocket(interactions.api.gateway.WebSocket):
-    def handle_dispatch(self, event: str, data: dict) -> None:
-        super().handle_dispatch(event, data)
-
-        if event == "INTERACTION_CREATE":
-            if "type" not in data:
-                return
-
-            context = self.contextualize(data)
-            self.dispatch.dispatch("on_interaction_create", context)
-
-            name: str = interactions.InteractionType(data["type"]).name
-            name = "on_" + name.lower()
-            self.dispatch.dispatch(name, context)
-
-
-interactions.api.gateway.WebSocket = ExtendedWebSocket
-
-
 async def wait_for(
     bot: interactions.Client,
     name: str,
@@ -86,11 +78,11 @@ async def wait_for(
     :rtype: Any
     """
     while True:
-        fut = bot._websocket.dispatch.add(name=name)
+        fut = bot._websocket._dispatch.add(name=name)
         try:
             res: list = await asyncio.wait_for(fut, timeout=timeout)
         except asyncio.TimeoutError:
-            bot._websocket.dispatch.extra_events[name].remove(fut)
+            bot._websocket._dispatch.extra_events[name].remove(fut)
             raise
 
         if check:
@@ -99,6 +91,7 @@ async def wait_for(
                 checked = await checked
             if not checked:
                 # The check failed, so try again next time
+                logger.info(f"A check failed waiting for the {name} event")
                 continue
 
         # I feel like this needs more?
@@ -169,26 +162,27 @@ async def wait_for_component(
 
     if messages:
         if isinstance(messages, interactions.Message):
-            messages_ids.append(messages.id)
-        elif isinstance(messages, int):
-            messages_ids.append(messages)
+            messages_ids.append(int(messages.id))
         elif isinstance(messages, list):
             for message in messages:
                 if isinstance(message, interactions.Message):
-                    messages_ids.append(message.id)
-                elif isinstance(message, int):
-                    messages_ids.append(message)
+                    messages_ids.append(int(message.id))
+                else:
+                    messages_ids.append(int(message))
+        else:  # account for plain ints, string, or Snowflakes
+            messages_ids.append(int(messages))
+
 
     def _check(ctx: interactions.ComponentContext) -> bool:
         if custom_ids and ctx.data.custom_id not in custom_ids:
             return False
-        if messages_ids and ctx.message.id not in messages_ids:
+        if messages_ids and int(ctx.message.id) not in messages_ids:
             return False
         if check:
             return check(ctx)
         return True
 
-    return await wait_for(bot, "on_message_component", check=_check, timeout=timeout)
+    return await wait_for(bot, "on_component", check=_check, timeout=timeout)
 
 
 def _replace_values(old, new):
@@ -209,7 +203,6 @@ def _replace_values(old, new):
 def setup(
     bot: interactions.Client,
     add_method: bool = False,
-    add_interaction_events: bool = True,
 ) -> None:
     """
     Apply hooks to a bot to add additional features
@@ -218,9 +211,10 @@ def setup(
 
     :param Client bot: The bot instance or class to apply hooks to
     :param bool add_method: If ``wait_for`` should be attached to the bot
-    :param bool add_interaction_events: Whether to add ``on_message_component``, ``on_application_command``, and other interaction event
     """
 
+    logger.info("Setting up the client")
+
     if not isinstance(bot, interactions.Client):
         raise TypeError(f"{bot.__class__.__name__} is not interactions.Client!")
 
@@ -228,20 +222,10 @@ def setup(
         bot.wait_for = types.MethodType(wait_for, bot)
         bot.wait_for_component = types.MethodType(wait_for_component, bot)
 
-    if add_interaction_events and not isinstance(bot._websocket, ExtendedWebSocket):
-        old_websocket = bot._websocket
-        new_websocket = ExtendedWebSocket(
-            old_websocket.intents, old_websocket.session_id, old_websocket.sequence
-        )
-
-        _replace_values(old_websocket, new_websocket)
-
-        bot._websocket = new_websocket
-
     # Overwrite the listener with the new one
-    if not isinstance(bot._websocket.dispatch, ExtendedListener):
+    if not isinstance(bot._websocket._dispatch, ExtendedListener):
         new_listener = ExtendedListener()
-        old_listener = bot._websocket.dispatch
+        old_listener = bot._websocket._dispatch
         new_listener.loop = old_listener.loop
         new_listener.events = old_listener.events
-        bot._websocket.dispatch = new_listener
+        bot._websocket._dispatch = new_listener
